@@ -11,7 +11,8 @@ FMM <- setClass("FMM", slots = c(
   beta="numeric",
   omega="numeric",
   SSE="numeric",
-  R2="numeric")
+  R2="numeric",
+  nIter="numeric")
 )
 
 
@@ -29,6 +30,7 @@ getSummarizedData <- function(objFMM) { objFMM@summarizedData }
 getFittedValues <- function(objFMM) { objFMM@fittedValues }
 getSSE <- function(objFMM) { objFMM@SSE }
 getR2 <- function(objFMM) { objFMM@R2 }
+getNIter <- function(objFMM) { objFMM@nIter }
 
 
 
